diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/Changelog b/Reconstruction/RecoAlgs/CaloRingerAlgs/Changelog
index 1de215f6cef71011cd4de8cb70205e4c280cf591..c1c802f7a079aff71ec6c7404bb8c57a2977f553 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/Changelog
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/Changelog
@@ -1,3 +1,47 @@
+2016-12-13  Werner Freund <wsfreund@cern.ch>
+
+	* Tagging CaloRingerAlgs-00-00-28.
+	* Changed RTT geometry to the file original.
+
+2016-12-13  scott snyder  <snyder@bnl.gov>
+
+	* Tagging CaloRingerAlgs-00-00-27.
+	* src/xAODRingSetConfWriter.cxx: DV const correctness.
+
+2016-12-11  Werner Freund <wsfreund@cern.ch>
+
+	* Tagging CaloRingerAlgs-00-00-26.
+	* Fixes previous premature tag upload.
+
+2016-12-11  Werner Freund <wsfreund@cern.ch>
+
+	* Tagging CaloRingerAlgs-00-00-25.
+	* Do not instantiate xAODRingSetConfWriter when CRBuilder is not available
+	and there is no ringer metadata in the input file.
+	* Updated ATN joboption to use a more up-to-date conditions tag (missing in
+	previous tag).
+
+2016-12-07  Werner Freund <wsfreund@cern.ch>
+
+	* Tagging CaloRingerAlgs-00-00-24.
+	* Included protection when no egammaGetter is available.
+	* Updated ATN joboption to use a more up-to-date conditions tag.
+
+2016-12-02  scott snyder  <snyder@bnl.gov>
+
+	* Tagging CaloRingerAlgs-00-00-23.
+	* Tool handle constness fixes.
+
+2016-11-30  Werner Freund <wsfreund@cern.ch>
+
+	*  Reduce metadata log verbosity.
+	*  Tagged as CaloRingerAlgs-00-00-22.
+
+2016-11-30  Werner Freund <wsfreund@cern.ch>
+
+	*  Updated ATN job
+	*  Tagged as CaloRingerAlgs-00-00-21.
+
 2016-11-30  Werner Freund <wsfreund@cern.ch>
 
 	*  Only run egamma calo rings builder when egammaBuilder is available.
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/python/CaloRingerMetaDataBuilder.py b/Reconstruction/RecoAlgs/CaloRingerAlgs/python/CaloRingerMetaDataBuilder.py
index d3cc55fa1d1d8bd2d2fdef84f5abd51f7c8e2b78..5f04176934e33717a0d62f452d54babc011cae3c 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/python/CaloRingerMetaDataBuilder.py
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/python/CaloRingerMetaDataBuilder.py
@@ -9,9 +9,6 @@ from CaloRingerAlgs.CaloRingerFlags import caloRingerFlags
 from CaloRingerAlgs.CaloRingerAlgorithmBuilder import removeFromTopSequence
 from egammaRec.Factories import AlgFactory, FcnWrapper
 
-# We assume that someone tried to configure the crBuild propertly before...
-from CaloRingerAlgs.CaloRingerAlgorithmBuilder import CaloRingerAlgorithmBuilder
-crBuilder = CaloRingerAlgorithmBuilder()
 
 
 from AthenaCommon.Logging import logging
@@ -19,6 +16,8 @@ from AthenaCommon.Logging import logging
 mlog = logging.getLogger( 'CaloRingerMetaDataBuilder.py' )
 mlog.info("Entering")
 
+# Flag whether we will overwrite input data
+_overwriting = False
 
 def metaDataInputAvailable(inputType, inputKey):
   """ metaDataInputAvailable(inputType, inputKey) 
@@ -37,31 +36,18 @@ def metaDataInputAvailable(inputType, inputKey):
       "key %s."), inputType, inputKey)
   return flag
 
-def getCaloRingerConfOutputs():
-  """   Returns a list with the RingSetConfWriter container names.  """
-
-  outputList = []
-  overwriting = False
-  builderNames = [tool.getName() for tool in crBuilder.getCaloRingerBuilderHandles()]
-
-  if any(['Electron' in builderName for builderName in builderNames]):
-    outputList.append(outputElectronRingSetsConfKey())
-    electronMetaAvailable = metaDataInputAvailable(outputRingSetConfType(), outputElectronRingSetsConfKey())
-    if electronMetaAvailable:
-      overwriting = True
-  if any(['Photon' in builderName for builderName in builderNames]):
-    outputList.append(outputPhotonRingSetsConfKey())
-    photonMetaAvailable = metaDataInputAvailable(outputRingSetConfType(), outputPhotonRingSetsConfKey())
-    if photonMetaAvailable:
-      overwriting = True
-  return outputList, overwriting
-
-
 class CaloRingerMetaDataBuilder ( Configured ):
+  """
+  Configure xAODRingSetConfWriter. 
+
+  NOTE: This must be done after setting CaloRingerAlgorithmBuilder.
+  """
 
   _confWriter = None
+  _overwriting = False
   _outputMetaData = {}
   _output = {}
+  _output = {}
 
   def getLastWriterHandle(self):
     "Return last CaloRinger algorithm to write into StoreGate Services."
@@ -85,6 +71,37 @@ class CaloRingerMetaDataBuilder ( Configured ):
     "Call Configured init, but with new default ignoreExistingDataObject"
     Configured.__init__(self,disable,ignoreExistingDataObject,ignoreConfigError)
 
+  def _setCaloRingerConfOutputs(self, metaBuilder):
+    """Setup metabuilder RingSetConfWriter container names."""
+    outputList = []
+    self._overwriting = False
+    from CaloRingerAlgs.CaloRingerAlgorithmBuilder import CaloRingerAlgorithmBuilder
+    crBuilder = CaloRingerAlgorithmBuilder()
+    if crBuilder.usable():
+      builderNames = [tool.getName() for tool in crBuilder.getCaloRingerBuilderHandles()]
+      if any(['Electron' in builderName for builderName in builderNames]):
+        outputList.append(outputElectronRingSetsConfKey())
+        electronMetaAvailable = metaDataInputAvailable(outputRingSetConfType(), outputElectronRingSetsConfKey())
+        if electronMetaAvailable:
+          self._overwriting = True
+      if any(['Photon' in builderName for builderName in builderNames]):
+        outputList.append(outputPhotonRingSetsConfKey())
+        photonMetaAvailable = metaDataInputAvailable(outputRingSetConfType(), outputPhotonRingSetsConfKey())
+        if photonMetaAvailable:
+         self. _overwriting = True
+    metaBuilder.RingSetConfContainerNames = outputList
+    self._outputMetaData = {outputRingSetConfType() : outputList }
+    self._output.update(self._outputMetaData)
+
+
+  def _setCaloRingsBuilderTools(self, metaBuilder):
+    """
+    Configure metaBuilder CaloRinger available builders.
+    """
+    from CaloRingerAlgs.CaloRingerAlgorithmBuilder import CaloRingerAlgorithmBuilder
+    crBuilder = CaloRingerAlgorithmBuilder()
+    metaBuilder.CaloRingsBuilderTools = crBuilder.getCaloRingerBuilderHandles()
+
   def configure(self):
     "This method will be called when object is initialized"
 
@@ -94,20 +111,16 @@ class CaloRingerMetaDataBuilder ( Configured ):
 
     # Instantiate the MetaDataWriter:
     try:
-      outputs, overwrite = getCaloRingerConfOutputs()
       MetaDataWriter = AlgFactory(CaloRingerAlgsConf.Ringer__xAODRingSetConfWriter, 
           name = "xAODRingSetConfWriter",
-          CaloRingsBuilderTools = crBuilder.getCaloRingerBuilderHandles(),
-          RingSetConfContainerNames = outputs,
+          postInit = [self._setCaloRingsBuilderTools, self._setCaloRingerConfOutputs]
           )
       self._confWriter = MetaDataWriter()
-      self._outputMetaData = {outputRingSetConfType() : outputs }
-      self._output.update(self._outputMetaData)
 
       # Check for existing output:
       self.checkExistingOutput()
 
-      if not self.ignoreExistingDataObject() and overwrite:
+      if not self.ignoreExistingDataObject() and self._overwriting:
         raise RuntimeError(("Already existing input will be overwriten and not set flag to"
             "ignoreExistingDataObject."))
 
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_ATN.py b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_ATN.py
index 60aee7e03cdd0bb80ba06889ac54744f3d413189..1775d0b06155593b123960dc4f8e6b81bf0b2c45 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_ATN.py
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_ATN.py
@@ -5,17 +5,19 @@
 #########################################################################
 from CaloRingerAlgs.CaloRingerFlags import caloRingerFlags
 caloRingerFlags.useAsymBuilder.set_Value_and_Lock(False)
+caloRingerFlags.buildElectronCaloRings.set_Value_and_Lock(True)
+caloRingerFlags.minElectronEnergy.set_Value_and_Lock(None)
 caloRingerFlags.doElectronIdentification.set_Value_and_Lock(True)
-caloRingerFlags.doPhotonIdentification.set_Value_and_Lock(True)
-caloRingerFlags.OutputLevel.set_Value_and_Lock(DEBUG)
-doCaloRinger = True
+caloRingerFlags.buildPhotonCaloRings.set_Value_and_Lock(True)
+caloRingerFlags.minPhotonEnergy.set_Value_and_Lock(None)
+caloRingerFlags.OutputLevel.set_Value_and_Lock(VERBOSE)
 #########################################################################
 
 ####################### CHANGE CONFIGURATION HERE  ######################
 #########################################################################
 doDumpStoreGate = False
-ManualDetDescrVersion = 'ATLAS-R2-2015-01-01-00' # Set to False or empty if you want it to be automatically set.
-ConditionsTag = "OFLCOND-RUN12-SDR-14"
+ManualDetDescrVersion = 'ATLAS-R2-2015-01-01-00'
+ConditionsTag = "CONDBR2-BLKPA-2016-11"
 from AtlasGeoModel.SetGeometryVersion import GeoModelSvc
 GeoModelSvc.IgnoreTagSupport = True
 GeoModelSvc.AtlasVersion = ManualDetDescrVersion
@@ -48,7 +50,9 @@ athenaCommonFlags.AllowIgnoreConfigError = False
 from AthenaCommon.AthenaCommonFlags import jobproperties
 jobproperties.AthenaCommonFlags.PoolRDOInput=jobproperties.AthenaCommonFlags.FilesInput.get_Value()
 from AthenaCommon.AthenaCommonFlags import athenaCommonFlags
-numEvt = -1 
+numEvt = 26
+if 'file' in dir():
+  athenaCommonFlags.PoolRDOInput = [file]
 athenaCommonFlags.EvtMax = numEvt
 athenaCommonFlags.PoolAODOutput = 'AOD.pool.root'
 from AthenaCommon.GlobalFlags import globalflags
@@ -75,8 +79,7 @@ include( "RecExCommon/RecExCommon_topOptions.py" )
 
 ###########################  Ringer!!! ##################################
 #########################################################################
-if doCaloRinger:
-  include('CaloRingerAlgs/CaloRinger_joboptions.py')
+include('CaloRingerAlgs/CaloRinger_jobOptions.py')
 #########################################################################
 
 ########################### POST-INCLUDE ################################
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/NeuralNetTests_Ref.txt b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/NeuralNetTests_Ref.txt
index 5a61fe59d6a2f0e3fa0046ebb3631c6a84b8b89e..4eb30ea80f81e203764f1667ba5123cfc2cbdc02 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/NeuralNetTests_Ref.txt
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/NeuralNetTests_Ref.txt
@@ -6,122 +6,122 @@ stdout: -- FileGrepResult --
   success: True
   vetoFlag: False
   matchLines [117]:
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.982403]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.132137]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.920065]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.982403]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.132137]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.920065]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.982403]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.132137]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.920065]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.944281]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.944281]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.944281]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.971032]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.607829]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.99175]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.99786]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999449]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.969697]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.975935]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.858042]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.971032]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.607829]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.99175]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.99786]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999449]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.969697]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.975935]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.858042]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.971032]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.607829]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.99175]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.99786]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999449]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.969697]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.975935]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.858042]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.65687]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.983238]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.65687]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.983238]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.65687]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.983238]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.994122]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.99696]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.959112]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.943786]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999757]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.190016]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.994122]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.99696]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.959112]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.943786]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999757]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.190016]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.994122]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.99696]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.959112]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.943786]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999757]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.190016]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.997905]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.997905]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.997905]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [0.33685]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [0.33685]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [0.33685]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.285056]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [0.229858]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.285056]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [0.229858]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.285056]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [0.229858]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.986561]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.992572]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.976097]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.99906]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.841992]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.872883]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.995145]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.985606]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.986561]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.992572]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.976097]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.99906]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.841992]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.872883]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.995145]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.985606]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.986561]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.992572]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.976097]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.99906]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.841992]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.872883]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.995145]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.985606]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.881858]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.881858]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.881858]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.74727]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.74727]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.74727]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.993071]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.998666]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.993071]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.998666]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.993071]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.998666]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.994398]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999743]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.994398]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999743]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.994398]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999743]
-    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.564306]
-    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.564306]
-    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.564306]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.538683]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.538683]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.538683]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.621306]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.621306]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.621306]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.996962]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.948311]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999008]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.993593]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.99887]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.996962]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.948311]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999008]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.993593]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.99887]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.996962]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.948311]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999008]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.993593]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.99887]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.563287]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.993328]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999104]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.563287]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.993328]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999104]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.563287]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.993328]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999104]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.997245]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.996499]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.992486]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.943482]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.996376]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999961]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.960854]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.997812]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.984893]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.993568]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.997245]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.996499]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.992486]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.943482]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.996376]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999961]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.960854]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.997812]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.984893]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.993568]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.997245]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.996499]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.992486]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.943482]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.996376]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999961]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.960854]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.997812]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.984893]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.993568]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.991852]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999668]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.991852]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999668]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.991852]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999668]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.103501]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.103501]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.103501]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999808]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [0.624281]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999808]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [0.624281]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999808]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [0.624281]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.995596]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.908205]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.991354]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.999076]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.95908]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.969097]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.994815]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.995596]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.908205]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.991354]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.999076]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.95908]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.969097]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.994815]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.995596]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.908205]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.991354]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.999076]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.95908]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.969097]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.994815]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.981325]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.951614]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.998283]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.981325]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.951614]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.998283]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.981325]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.951614]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.998283]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.970742]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.970742]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.970742]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.981591]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.982775]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.981591]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.982775]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.981591]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.982775]
+    ToolSvc.ElectronRingerSelector_TestLoose            DEBUG Applying UniqueThreshold (Value: 0.948). Output space is: [-0.998898]
+    ToolSvc.ElectronRingerSelector_TestMedium           DEBUG Applying UniqueThreshold (Value: 0.2644). Output space is: [-0.998898]
+    ToolSvc.ElectronRingerSelector_TestTight            DEBUG Applying UniqueThreshold (Value: 0.2826). Output space is: [-0.998898]
 
-stderr: 
\ No newline at end of file
+stderr: 
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/src/CaloRingerAlgorithm.cxx b/Reconstruction/RecoAlgs/CaloRingerAlgs/src/CaloRingerAlgorithm.cxx
index 56487f2d068be0c225f6b0dede1ef8ba58a02b0c..44d5d4cf986b1efd47c78988beb2a82a7b437c5e 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/src/CaloRingerAlgorithm.cxx
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/src/CaloRingerAlgorithm.cxx
@@ -2,7 +2,7 @@
   Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
 */
 
-// $Id: CaloRingerAlgorithm.cxx 785784 2016-11-22 16:38:22Z wsfreund $
+// $Id: CaloRingerAlgorithm.cxx 787810 2016-12-02 05:39:13Z ssnyder $
 #include "CaloRingerAlgorithm.h"
 
 // Framework includes:
@@ -75,7 +75,7 @@ StatusCode CaloRingerAlgorithm::execute()
   ATH_MSG_DEBUG ("Executing " << name() << ".");
 
   // Loop over input readers
-  for (const auto& readerTool : m_inputReaders)
+  for (auto& readerTool : m_inputReaders)
   {
     ATH_MSG_DEBUG ("Executing Reader tool " << readerTool.name() << ".");
 
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/src/xAODRingSetConfWriter.cxx b/Reconstruction/RecoAlgs/CaloRingerAlgs/src/xAODRingSetConfWriter.cxx
index 8755c4701d9f96c78d972ecd003896a3b8e4fe84..81a11c446cb4e1392cfed06e6a6f1e85f6fbf80c 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/src/xAODRingSetConfWriter.cxx
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/src/xAODRingSetConfWriter.cxx
@@ -2,7 +2,7 @@
   Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
 */
 
-// $Id: xAODRingSetConfWriter.cxx 786303 2016-11-24 13:38:29Z wsfreund $
+// $Id: xAODRingSetConfWriter.cxx 787810 2016-12-02 05:39:13Z ssnyder $
 
 // STL include(s)
 #include <algorithm>
@@ -107,9 +107,9 @@ StatusCode xAODRingSetConfWriter::initialize() {
   ATH_MSG_DEBUG("There are available a total of " << m_rsConfContVec.size() << " RingSetConfContainer(s).");
   for ( const auto* c : m_rsConfContVec ) {
     if ( nullptr != c ) {
-      if ( msg().level() <= MSG::DEBUG ) {
+      if ( msg().level() <= MSG::VERBOSE ) {
         for ( const auto& r : *c ){
-          r->print( msg(), MSG::DEBUG );
+          r->print( msg(), MSG::VERBOSE );
         }
       }
     } else {
@@ -194,15 +194,16 @@ StatusCode xAODRingSetConfWriter::copyKeyToStore( const std::string &key )
   // Copy them:
   contCopy->reserve( cont->size() );
   contAuxCopy->reserve( cont->size() );
+  ATH_MSG_DEBUG("Copying object with key: " << key);
   for ( value_type obj : *cont ) {
+    ATH_MSG_VERBOSE("Original object:");
     // Print-out object:
-    ATH_MSG_DEBUG("Original object with key: " << key);
-    obj->print( msg(), MSG::DEBUG ); 
+    obj->print( msg(), MSG::VERBOSE ); 
     // Copy object
     value_type objCopy = new (base_value_type)( *obj );
     // Print-out object:
-    ATH_MSG_DEBUG("Copied object which will be recorded with same key: " << key);
-    objCopy->print( msg(), MSG::DEBUG ); 
+    ATH_MSG_VERBOSE("Copied object:");
+    objCopy->print( msg(), MSG::VERBOSE ); 
     // Add to container
     contCopy->push_back( objCopy );
   }
@@ -259,7 +260,7 @@ StatusCode xAODRingSetConfWriter::fillConfigurations()
 
   for (size_t counter = 0; counter < m_rsConfContVec.size(); ++counter)
   {
-    const auto& crBuilder = m_crBuilderTools[counter];
+    auto& crBuilder = m_crBuilderTools[counter];
     auto& rsCont = m_rsConfContVec[counter];
 
     // Create the xAOD configuration object (it will populate
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/test/CaloRingerAlgs_TestConfiguration.xml b/Reconstruction/RecoAlgs/CaloRingerAlgs/test/CaloRingerAlgs_TestConfiguration.xml
index 7067cd4cda0ee707a3699eb6df6372cd9beaaef8..85c9fdfac4fdb418203b33c484df18fd4f3cc379 100755
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/test/CaloRingerAlgs_TestConfiguration.xml
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/test/CaloRingerAlgs_TestConfiguration.xml
@@ -11,116 +11,116 @@
         <chainName>MyChainJob</chainName>
         <sequential> 
         <chainElement>
-      <athena userJobId="caloringeralgs">
-        <doc>Test of output CaloRinger</doc>
-        <options>CaloRingerAlgs/CaloRinger_ATN</options> 
-        <group>RTT:Athena</group>
-        <queue>medium</queue>
-        <dataset_info>
-          <dc2 />
+        <athena userJobId="caloringeralgs">
+          <doc>CaloRinger Algorithm Nightly Test</doc>
+          <options>CaloRingerAlgs/CaloRinger_ATN</options> 
+          <group>RTT:Athena</group>
+          <queue>medium</queue>
+          <dataset_info>
+            <dc2 />
 
-          <datasetName>/afs/cern.ch/atlas/project/rig/referencefiles/QTests-Run2/RDO-run2.Nov27.2014-500events.pool.root</datasetName>
-            </dataset_info>
-          
-            <test position="1">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileGrepper</testname>
-              <outputFile>myRingSetFile.txt</outputFile>
-              <arg>
-                <argname>inputFile</argname>
-                <argvalue>caloringeralgs_log</argvalue>
-              </arg>
-              <arg>
-                <argname>searchList</argname>
-                <argvalue>Ringset</argvalue>
-              </arg>
-              <keepFilePattern>myRingSetFile.txt</keepFilePattern>
-            </test>
+            <datasetName>/afs/cern.ch/atlas/project/rig/referencefiles/QTests-Run2/RDO-run2.Nov27.2014-500events.pool.root</datasetName>
+              </dataset_info>
+            
+              <test position="1">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileGrepper</testname>
+                <outputFile>myRingSetFile.txt</outputFile>
+                <arg>
+                  <argname>inputFile</argname>
+                  <argvalue>caloringeralgs_log</argvalue>
+                </arg>
+                <arg>
+                  <argname>searchList</argname>
+                  <argvalue>Ringset</argvalue>
+                </arg>
+                <keepFilePattern>myRingSetFile.txt</keepFilePattern>
+              </test>
 
-            <test position="2">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileComparatorRunner</testname>
-              <outputFile>myRingComparatorFile.txt</outputFile>
-              <arg>
-                <argname>testFile</argname>
-                <argvalue>myRingSetFile.txt</argvalue>
-              </arg>
-              <arg>
-                <argname>refFile</argname>
-                <argvalue>RingerTests_Builders.txt</argvalue>
-              </arg>
-              <keepFilePattern>myRingComparatorFile.txt</keepFilePattern>
-              <noalarm/>
-            </test>
+              <test position="2">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileComparatorRunner</testname>
+                <outputFile>myRingComparatorFile.txt</outputFile>
+                <arg>
+                  <argname>testFile</argname>
+                  <argvalue>myRingSetFile.txt</argvalue>
+                </arg>
+                <arg>
+                  <argname>refFile</argname>
+                  <argvalue>RingerTests_Builders.txt</argvalue>
+                </arg>
+                <keepFilePattern>myRingComparatorFile.txt</keepFilePattern>
+                <noalarm/>
+              </test>
 
-            <test position="3">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileGrepper</testname>
-              <outputFile>myNeuralNetOutput.txt</outputFile>
-              <arg>
-                <argname>inputFile</argname>
-                <argvalue>caloringeralgs_log</argvalue>
-              </arg>
-              <arg>
-                <argname>searchList</argname>
-                <argvalue>Output space</argvalue>
-              </arg>
-              <keepFilePattern>myNeuralNetOutput.txt</keepFilePattern>
-            </test>
+              <test position="3">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileGrepper</testname>
+                <outputFile>myNeuralNetOutput.txt</outputFile>
+                <arg>
+                  <argname>inputFile</argname>
+                  <argvalue>caloringeralgs_log</argvalue>
+                </arg>
+                <arg>
+                  <argname>searchList</argname>
+                  <argvalue>Output space</argvalue>
+                </arg>
+                <keepFilePattern>myNeuralNetOutput.txt</keepFilePattern>
+              </test>
 
-            <test position="4">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileComparatorRunner</testname>
-              <outputFile>myNetComparatorFile.txt</outputFile>
-              <arg>
-                <argname>testFile</argname>
-                <argvalue>myNeuralNetOutput.txt</argvalue>
-              </arg>
-              <arg>
-                <argname>refFile</argname>
-                <argvalue>NeuralNetTests_Ref.txt</argvalue>
-              </arg>
-              <keepFilePattern>myNetComparatorFile.txt</keepFilePattern>
-              <noalarm/>
-            </test>
+              <test position="4">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileComparatorRunner</testname>
+                <outputFile>myNetComparatorFile.txt</outputFile>
+                <arg>
+                  <argname>testFile</argname>
+                  <argvalue>myNeuralNetOutput.txt</argvalue>
+                </arg>
+                <arg>
+                  <argname>refFile</argname>
+                  <argvalue>NeuralNetTests_Ref.txt</argvalue>
+                </arg>
+                <keepFilePattern>myNetComparatorFile.txt</keepFilePattern>
+                <noalarm/>
+              </test>
 
-            <test position="5">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileGrepper</testname>
-              <outputFile>RingComparator_OK.txt</outputFile>
-              <arg>
-                <argname>inputFile</argname>
-                <argvalue>myRingComparatorFile.txt</argvalue>
-              </arg>
-              <arg>
-                <argname>vetoList</argname>
-                <argvalue>DEBUG Ringset</argvalue>
-              </arg>
-              <keepFilePattern>RingComparator_OK.txt</keepFilePattern>
-            </test>
+              <test position="5">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileGrepper</testname>
+                <outputFile>RingComparator_OK.txt</outputFile>
+                <arg>
+                  <argname>inputFile</argname>
+                  <argvalue>myRingComparatorFile.txt</argvalue>
+                </arg>
+                <arg>
+                  <argname>vetoList</argname>
+                  <argvalue>DEBUG Ringset</argvalue>
+                </arg>
+                <keepFilePattern>RingComparator_OK.txt</keepFilePattern>
+              </test>
 
-            <test position="6">
-              <modulename>RttLibraryTools</modulename>
-              <testname>FileGrepper</testname>
-              <outputFile>NetComparator_OK.txt</outputFile>
-              <arg>
-                <argname>inputFile</argname>
-                <argvalue>myNetComparatorFile.txt</argvalue>
-              </arg>
-              <arg>
-                <argname>vetoList</argname>
-                <argvalue>Output space</argvalue>
-              </arg>
-              <keepFilePattern>NetComparator_OK.txt</keepFilePattern>
-            </test>
+              <test position="6">
+                <modulename>RttLibraryTools</modulename>
+                <testname>FileGrepper</testname>
+                <outputFile>NetComparator_OK.txt</outputFile>
+                <arg>
+                  <argname>inputFile</argname>
+                  <argvalue>myNetComparatorFile.txt</argvalue>
+                </arg>
+                <arg>
+                  <argname>vetoList</argname>
+                  <argvalue>Output space</argvalue>
+                </arg>
+                <keepFilePattern>NetComparator_OK.txt</keepFilePattern>
+              </test>
 
               <auxFilePattern>myRingComparatorFile.txt</auxFilePattern>
               <auxFilePattern>myNetComparatorFile.txt</auxFilePattern>
               <auxFilePattern>RingerTests_Builders.txt</auxFilePattern>
               <auxFilePattern>NeuralNetTests_Ref.txt</auxFilePattern>
             </athena>
-        </chainElement>
-      </sequential>
+          </chainElement>
+        </sequential>
       </chain>
     </jobList>
diff --git a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_jobOptions.py b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_jobOptions.py
index f76213e4e8a81ea8596d83c61369397b531193a0..fc9a5169ec8f0808528cf8bce732bf3b46fddac8 100644
--- a/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_jobOptions.py
+++ b/Reconstruction/RecoAlgs/CaloRingerAlgs/share/CaloRinger_jobOptions.py
@@ -4,6 +4,7 @@ from AthenaCommon.Logging import logging
 
 from CaloRingerAlgs.CaloRingerFlags import caloRingerFlags
 from CaloRingerAlgs.CaloRingerAlgorithmBuilder import CaloRingerAlgorithmBuilder
+from CaloRingerAlgs.CaloRingerMetaDataBuilder import CaloRingerMetaDataBuilder
 
 mlog = logging.getLogger( 'CaloRinger_joboptions.py' )
 mlog.info('Entering')
@@ -14,7 +15,8 @@ ringerOutputLevel = caloRingerFlags.OutputLevel()
 # ringer:
 if caloRingerFlags.buildCaloRingsOn():
   # Check egamma related objects:
-  if not rec.doEgamma():
+  from egammaRec.egammaGetter import egammaGetter
+  if not rec.doEgamma() or egammaGetter().disabled():
     if caloRingerFlags.buildElectronCaloRings():
       caloRingerFlags.buildElectronCaloRings.set_Value( False )
       caloRingerFlags.doElectronIdentification.set_Value( False )
@@ -45,10 +47,8 @@ if caloRingerFlags.buildCaloRingsOn() or caloRingerFlags.doIdentificationOn():
 
   # Make sure all algoritms have the ringerOutputLevel
   if CRAlgBuilder.usable():
-
     # Get the main logger algorithm
     mainAlg = CRAlgBuilder.getCaloRingerAlgHandle()
-
     if mainAlg:
       # Change the main algorithm output level
       mlog.verbose('Changing %r output level to %s', mainAlg, ringerOutputLevel)
@@ -63,7 +63,6 @@ if caloRingerFlags.buildCaloRingsOn() or caloRingerFlags.doIdentificationOn():
 
     # Get the builder handles
     builderHandles = CRAlgBuilder.getCaloRingerBuilders()
-
     for builder in builderHandles:
       # Change builders output level
       mlog.verbose('Changing %r output level to %s', builder, ringerOutputLevel)
@@ -71,28 +70,30 @@ if caloRingerFlags.buildCaloRingsOn() or caloRingerFlags.doIdentificationOn():
 
     # Get the selector handles
     selectorHandles = CRAlgBuilder.getRingerSelectors()
-
     for selector in selectorHandles:
       # Change the builders output level
       mlog.verbose('Changing %r output level to %s', selector, ringerOutputLevel)
       selector.OutputLevel = ringerOutputLevel
-
 else:
-
   # Otherwise we disable the main algorithm
   CRAlgBuilder = CaloRingerAlgorithmBuilder( disable = True )
 
 # Add metadata builder/reader
-from CaloRingerAlgs.CaloRingerMetaDataBuilder import CaloRingerMetaDataBuilder
-MetaDataBuilder = CaloRingerMetaDataBuilder()
-
-# Make sure all MetaData algoritms have the ringerOutputLevel
-if MetaDataBuilder.usable():
-  # Get the ringer configuration writter handle
-  configWriter = MetaDataBuilder.getConfigWriterHandle()
-
-  if configWriter:
-    # Change its output level
-    mlog.verbose('Changing %r output level to %s', configWriter, ringerOutputLevel)
-    configWriter.OutputLevel = ringerOutputLevel
+from RecExConfig.InputFilePeeker import inputFileSummary
+metaItemDict = inputFileSummary.get( 'metadata_itemsDic' )
+if CRAlgBuilder.usable() or any( ['RingSetConf' in key for key in metaItemDict ] ):
+  MetaDataBuilder = CaloRingerMetaDataBuilder()
+
+  # Make sure all MetaData algoritms have the ringerOutputLevel
+  if MetaDataBuilder.usable():
+    # Get the ringer configuration writter handle
+    configWriter = MetaDataBuilder.getConfigWriterHandle()
+
+    if configWriter:
+      # Change its output level
+      mlog.verbose('Changing %r output level to %s', configWriter, ringerOutputLevel)
+      configWriter.OutputLevel = ringerOutputLevel
+else:
+  # Otherwise we disable the metadata algorith:
+  MetaDataBuilder = CaloRingerMetaDataBuilder( disable = True)
 